﻿# This file is in the public domain. Feel free to modify it as a basis
# for your own screens.

##############################################################################
# Say
#
# Screen that's used to display adv-mode dialogue.
# http://www.renpy.org/doc/html/screen_special.html#say
screen say:

    # Defaults for side_image and two_window
    default side_image = None
    default two_window = False

    # Decide if we want to use the one-window or two-window varaint.
    if not two_window:

        # The one window variant.        
        window:
            id "window"

            has vbox:
                style "say_vbox"

            if who:
                text who id "who"

            text what id "what"

    else:

        # The two window variant.
        vbox:
            style "say_two_window_vbox"

            if who:            
                window:
                    style "say_who_window"

                    text who:
                        id "who"
                        
            window:
                id "window"

                has vbox:
                    style "say_vbox"

                text what id "what"
              
    # If there's a side image, display it above the text.
    if side_image:
        add side_image
    else:
        add SideImage() xalign 0.0 yalign 1.0

    # Use the quick menu.
    use quick_menu


##############################################################################
# Choice
#
# Screen that's used to display in-game menus.
# http://www.renpy.org/doc/html/screen_special.html#choice

screen choice:

    window: 
        style "menu_window"        
        xalign 0.5
        yalign 0.5
        
        vbox:
            style "menu"
            spacing 2
            
            for caption, action, chosen in items:
                
                if action:  
                    
                    button:
                        action action
                        style "menu_choice_button"                        

                        text caption style "menu_choice"
                    
                else:
                    text caption style "menu_caption"

init -2 python:
    config.narrator_menu = True
    
    style.menu_window.set_parent(style.default)
    style.menu_choice.set_parent(style.button_text)
    style.menu_choice.clear()
    style.menu_choice_button.set_parent(style.button)
    style.menu_choice_button.xminimum = int(config.screen_width * 0.75)
    style.menu_choice_button.xmaximum = int(config.screen_width * 0.75)


##############################################################################
# Input
#
# Screen that's used to display renpy.input()
# http://www.renpy.org/doc/html/screen_special.html#input

screen input:

    window style "input_window":
        has vbox

        text prompt style "input_prompt"
        input id "input" style "input_text"

    use quick_menu
        
##############################################################################
# Nvl
#
# Screen used for nvl-mode dialogue and menus.
# http://www.renpy.org/doc/html/screen_special.html#nvl

screen nvl:

    window:
        style "nvl_window"

        has vbox:
            style "nvl_vbox"

        # Display dialogue.
        for who, what, who_id, what_id, window_id in dialogue:
            window:
                id window_id

                has hbox:
                    spacing 10

                if who is not None:
                    text who id who_id

                text what id what_id

        # Display a menu, if given.
        if items:

            vbox:
                id "menu"

                for caption, action, chosen in items:

                    if action:

                        button:
                            style "nvl_menu_choice_button"
                            action action

                            text caption style "nvl_menu_choice"

                    else:

                        text caption style "nvl_dialogue"

    add SideImage() xalign 0.0 yalign 1.0
    
    use quick_menu
        
##############################################################################
# Main Menu 
#
# Screen that's used to display the main menu, when Ren'Py first starts
# http://www.renpy.org/doc/html/screen_special.html#main-menu

screen main_menu:

    # This ensures that any other menu screen is replaced.
    tag menu

    # The background of the main menu.
    window:
        style "mm_root"

    # The main menu buttons.
    frame:
        style_group "mm"
        xalign .98
        yalign .98

        has vbox

        textbutton _("Start Game") action Start()
        textbutton _("Load Game") action ShowMenu("load")
        textbutton _("Gallery") action ShowMenu("gallery_1")
        textbutton _("Preferences") action ShowMenu("preferences")
        textbutton _("Help") action Help()
        textbutton _("Quit") action Quit(confirm=False)

init -2 python:

    # Make all the main menu buttons be the same size.
    style.mm_button.size_group = "mm"


##############################################################################
# Navigation
#
# Screen that's included in other screens to display the game menu
# navigation and background.
# http://www.renpy.org/doc/html/screen_special.html#navigation
screen navigation:

    # The background of the game menu.
    window:
        style "gm_root"

    # The various buttons.
    frame:
        style_group "gm_nav"
        xalign .98
        yalign .98
        
        has vbox

        textbutton _("Return") action Return()
        textbutton _("Preferences") action ShowMenu("preferences")
        textbutton _("Save Game") action ShowMenu("save")
        textbutton _("Load Game") action ShowMenu("load")
        textbutton _("Main Menu") action MainMenu()
        textbutton _("Help") action Help()
        textbutton _("Quit") action Quit()

init -2 python:
    style.gm_nav_button.size_group = "gm_nav"
    

##############################################################################
# Save, Load
#
# Screens that allow the user to save and load the game.
# http://www.renpy.org/doc/html/screen_special.html#save
# http://www.renpy.org/doc/html/screen_special.html#load

# Since saving and loading are so similar, we combine them into
# a single screen, file_picker. We then use the file_picker screen
# from simple load and save screens.
    
screen file_picker:

    frame:
        style "file_picker_frame"

        has vbox

        # The buttons at the top allow the user to pick a
        # page of files.
        hbox:
            style_group "file_picker_nav"
            
            textbutton _("Previous"):
                action FilePagePrevious()

            textbutton _("Auto"):
                action FilePage("auto")

            textbutton _("Quick"):
                action FilePage("quick")

            for i in range(1, 9):
                textbutton str(i):
                    action FilePage(i)
                    
            textbutton _("Next"):
                action FilePageNext()

        $ columns = 2
        $ rows = 5
                
        # Display a grid of file slots.
        grid columns rows:
            transpose True
            xfill True
            style_group "file_picker"
            
            # Display ten file slots, numbered 1 - 10.
            for i in range(1, columns * rows + 1):

                # Each file slot is a button.
                button:
                    action FileAction(i)
                    xfill True

                    has hbox

                    # Add the screenshot.
                    add FileScreenshot(i)
                    
                    $ file_name = FileSlotName(i, columns * rows)
                    $ file_time = FileTime(i, empty=_("Empty Slot."))
                    $ save_name = FileSaveName(i)

                    text "[file_name]. [file_time!t]\n[save_name!t]"

                    key "save_delete" action FileDelete(i)
                    
                    
screen save:

    # This ensures that any other menu screen is replaced.
    tag menu

    use navigation
    use file_picker

screen load:

    # This ensures that any other menu screen is replaced.
    tag menu

    use navigation
    use file_picker

init -2 python:
    style.file_picker_frame = Style(style.menu_frame)

    style.file_picker_nav_button = Style(style.small_button)
    style.file_picker_nav_button_text = Style(style.small_button_text)

    style.file_picker_button = Style(style.large_button)
    style.file_picker_text = Style(style.large_button_text)
    
    
##############################################################################
# Gallery
#
# Screen that's used to display unlocked CGs.

init python:
    
    g = Gallery()
    
    g.button("red")
    g.image("red1")
    g.unlock("red1")
    
    g.button("orange")
    g.image("orange1")
    g.unlock("orange1")
    
    g.button("yellow")
    g.image("yellowq")
    g.unlock("yellow1")
    
    
    g.button("green")
    g.image("green1")
    g.unlock("green1")
    
    g.button("light-blue")
    g.image("light-blue1")
    g.unlock("light-blue1")
    
    g.button("dark-blue")
    g.image("dark-blue1")
    g.unlock("dark-blue1")
    
    
    g.button("purple")
    g.image("purple1")
    g.unlock("purple1")
    
    g.button("pink")
    g.image("pink1")
    g.unlock("pink1")
    

screen gallery_1:

    # Ensure this replaces the main menu.
    tag menu

    # The background.
    add "logo"

    # A grid of buttons.
    grid 3 3:

        xfill True
        yfill True

        # Call make_button to show a particular button.
        add g.make_button("red", "red.png", xalign=0.5, yalign=0.5)
        add g.make_button("orange", "orange.png", xalign=0.5, yalign=0.5)
        add g.make_button("yellow", "yellow.png", xalign=0.5, yalign=0.5)

        add g.make_button("green", "green.png", xalign=0.5, yalign=0.5)
        add g.make_button("light-blue", "light-blue.png", xalign=0.5, yalign=0.5)
        add g.make_button("dark-blue", "dark-blue.png", xalign=0.5, yalign=0.5)

        add g.make_button("purple", "purple.png", xalign=0.5, yalign=0.5)
        add g.make_button("pink", "pink.png", xalign=0.5, yalign=0.5)

        # The screen is responsible for returning to the main menu. It could also
        # navigate to other gallery screens.
        
        grid 1 9:
            
            xfill True
            yfill True
        
            textbutton "Page 01" action ShowMenu("gallery_1")
            textbutton "Page 02" action ShowMenu("gallery_2")
            textbutton "Page 03" action ShowMenu("gallery_3")
            textbutton "Page 04" action ShowMenu("gallery_4")
            textbutton "Page 05" action ShowMenu("gallery_5")
            textbutton "Page 06" action ShowMenu("gallery_6")
            textbutton "Page 07" action ShowMenu("gallery_7")
            textbutton "Page 08" action ShowMenu("gallery_8")
            textbutton "Return" action Return() xalign 0.5 yalign 0.5
        
    
screen gallery_2:

    # Ensure this replaces the main menu.
    tag menu

    # The background.
    add "logo"

    # A grid of buttons.
    grid 3 3:

        xfill True
        yfill True

        # Call make_button to show a particular button.
        
        add g.make_button("orange", "orange.png", xalign=0.5, yalign=0.5)
        add g.make_button("yellow", "yellow.png", xalign=0.5, yalign=0.5)
        add g.make_button("green", "green.png", xalign=0.5, yalign=0.5)
        
        add g.make_button("light-blue", "light-blue.png", xalign=0.5, yalign=0.5)
        add g.make_button("dark-blue", "dark-blue.png", xalign=0.5, yalign=0.5)
        add g.make_button("purple", "purple.png", xalign=0.5, yalign=0.5)
        
        add g.make_button("pink", "pink.png", xalign=0.5, yalign=0.5)
        add g.make_button("red", "red.png", xalign=0.5, yalign=0.5)
        

        # The screen is responsible for returning to the main menu. It could also
        # navigate to other gallery screens.
        
        grid 1 9:
            
            xfill True
            yfill True
        
            textbutton "Page 01" action ShowMenu("gallery_1")
            textbutton "Page 02" action ShowMenu("gallery_2")
            textbutton "Page 03" action ShowMenu("gallery_3")
            textbutton "Page 04" action ShowMenu("gallery_4")
            textbutton "Page 05" action ShowMenu("gallery_5")
            textbutton "Page 06" action ShowMenu("gallery_6")
            textbutton "Page 07" action ShowMenu("gallery_7")
            textbutton "Page 08" action ShowMenu("gallery_8")
            textbutton "Return" action Return() xalign 0.5 yalign 0.5
        
        
screen gallery_3:

    # Ensure this replaces the main menu.
    tag menu

    # The background.
    add "logo"

    # A grid of buttons.
    grid 3 3:

        xfill True
        yfill True

        # Call make_button to show a particular button.
        
        add g.make_button("yellow", "yellow.png", xalign=0.5, yalign=0.5)
        add g.make_button("green", "green.png", xalign=0.5, yalign=0.5)        
        add g.make_button("light-blue", "light-blue.png", xalign=0.5, yalign=0.5)
        
        add g.make_button("dark-blue", "dark-blue.png", xalign=0.5, yalign=0.5)
        add g.make_button("purple", "purple.png", xalign=0.5, yalign=0.5)        
        add g.make_button("pink", "pink.png", xalign=0.5, yalign=0.5)
        
        add g.make_button("red", "red.png", xalign=0.5, yalign=0.5)
        add g.make_button("orange", "orange.png", xalign=0.5, yalign=0.5)

        # The screen is responsible for returning to the main menu. It could also
        # navigate to other gallery screens.
        
        grid 1 9:
            
            xfill True
            yfill True
        
            textbutton "Page 01" action ShowMenu("gallery_1")
            textbutton "Page 02" action ShowMenu("gallery_2")
            textbutton "Page 03" action ShowMenu("gallery_3")
            textbutton "Page 04" action ShowMenu("gallery_4")
            textbutton "Page 05" action ShowMenu("gallery_5")
            textbutton "Page 06" action ShowMenu("gallery_6")
            textbutton "Page 07" action ShowMenu("gallery_7")
            textbutton "Page 08" action ShowMenu("gallery_8")
            textbutton "Return" action Return() xalign 0.5 yalign 0.5
        
        
screen gallery_4:

    # Ensure this replaces the main menu.
    tag menu

    # The background.
    add "logo"

    # A grid of buttons.
    grid 3 3:

        xfill True
        yfill True

        # Call make_button to show a particular button.
        
        add g.make_button("green", "green.png", xalign=0.5, yalign=0.5)        
        add g.make_button("light-blue", "light-blue.png", xalign=0.5, yalign=0.5)        
        add g.make_button("dark-blue", "dark-blue.png", xalign=0.5, yalign=0.5)
        
        add g.make_button("purple", "purple.png", xalign=0.5, yalign=0.5)        
        add g.make_button("pink", "pink.png", xalign=0.5, yalign=0.5)        
        add g.make_button("red", "red.png", xalign=0.5, yalign=0.5)
        
        add g.make_button("orange", "orange.png", xalign=0.5, yalign=0.5)
        add g.make_button("yellow", "yellow.png", xalign=0.5, yalign=0.5)

        # The screen is responsible for returning to the main menu. It could also
        # navigate to other gallery screens.
        
        grid 1 9:
            
            xfill True
            yfill True
        
            textbutton "Page 01" action ShowMenu("gallery_1")
            textbutton "Page 02" action ShowMenu("gallery_2")
            textbutton "Page 03" action ShowMenu("gallery_3")
            textbutton "Page 04" action ShowMenu("gallery_4")
            textbutton "Page 05" action ShowMenu("gallery_5")
            textbutton "Page 06" action ShowMenu("gallery_6")
            textbutton "Page 07" action ShowMenu("gallery_7")
            textbutton "Page 08" action ShowMenu("gallery_8")
            textbutton "Return" action Return() xalign 0.5 yalign 0.5
        
        
screen gallery_5:

    # Ensure this replaces the main menu.
    tag menu

    # The background.
    add "logo"

    # A grid of buttons.
    grid 3 3:

        xfill True
        yfill True

        # Call make_button to show a particular button.
        
        add g.make_button("light-blue", "light-blue.png", xalign=0.5, yalign=0.5)        
        add g.make_button("dark-blue", "dark-blue.png", xalign=0.5, yalign=0.5)        
        add g.make_button("purple", "purple.png", xalign=0.5, yalign=0.5)
        
        add g.make_button("pink", "pink.png", xalign=0.5, yalign=0.5)        
        add g.make_button("red", "red.png", xalign=0.5, yalign=0.5)        
        add g.make_button("orange", "orange.png", xalign=0.5, yalign=0.5)
        
        add g.make_button("yellow", "yellow.png", xalign=0.5, yalign=0.5)
        add g.make_button("green", "green.png", xalign=0.5, yalign=0.5)

        # The screen is responsible for returning to the main menu. It could also
        # navigate to other gallery screens.
        
        grid 1 9:
            
            xfill True
            yfill True
        
            textbutton "Page 01" action ShowMenu("gallery_1")
            textbutton "Page 02" action ShowMenu("gallery_2")
            textbutton "Page 03" action ShowMenu("gallery_3")
            textbutton "Page 04" action ShowMenu("gallery_4")
            textbutton "Page 05" action ShowMenu("gallery_5")
            textbutton "Page 06" action ShowMenu("gallery_6")
            textbutton "Page 07" action ShowMenu("gallery_7")
            textbutton "Page 08" action ShowMenu("gallery_8")
            textbutton "Return" action Return() xalign 0.5 yalign 0.5
        
        
screen gallery_6:

    # Ensure this replaces the main menu.
    tag menu

    # The background.
    add "logo"

    # A grid of buttons.
    grid 3 3:

        xfill True
        yfill True

        # Call make_button to show a particular button.
        
        add g.make_button("dark-blue", "dark-blue.png", xalign=0.5, yalign=0.5)        
        add g.make_button("purple", "purple.png", xalign=0.5, yalign=0.5)        
        add g.make_button("pink", "pink.png", xalign=0.5, yalign=0.5)
        
        add g.make_button("red", "red.png", xalign=0.5, yalign=0.5)        
        add g.make_button("orange", "orange.png", xalign=0.5, yalign=0.5)        
        add g.make_button("yellow", "yellow.png", xalign=0.5, yalign=0.5)
        
        add g.make_button("green", "green.png", xalign=0.5, yalign=0.5)
        add g.make_button("light-blue", "light-blue.png", xalign=0.5, yalign=0.5)

        # The screen is responsible for returning to the main menu. It could also
        # navigate to other gallery screens.
        
        grid 1 9:
            
            xfill True
            yfill True
        
            textbutton "Page 01" action ShowMenu("gallery_1")
            textbutton "Page 02" action ShowMenu("gallery_2")
            textbutton "Page 03" action ShowMenu("gallery_3")
            textbutton "Page 04" action ShowMenu("gallery_4")
            textbutton "Page 05" action ShowMenu("gallery_5")
            textbutton "Page 06" action ShowMenu("gallery_6")
            textbutton "Page 07" action ShowMenu("gallery_7")
            textbutton "Page 08" action ShowMenu("gallery_8")
            textbutton "Return" action Return() xalign 0.5 yalign 0.5
        
        
screen gallery_7:

    # Ensure this replaces the main menu.
    tag menu

    # The background.
    add "logo"

    # A grid of buttons.
    grid 3 3:

        xfill True
        yfill True

        # Call make_button to show a particular button.
        
        add g.make_button("purple", "purple.png", xalign=0.5, yalign=0.5)        
        add g.make_button("pink", "pink.png", xalign=0.5, yalign=0.5)        
        add g.make_button("red", "red.png", xalign=0.5, yalign=0.5)
        
        add g.make_button("orange", "orange.png", xalign=0.5, yalign=0.5)        
        add g.make_button("yellow", "yellow.png", xalign=0.5, yalign=0.5)        
        add g.make_button("green", "green.png", xalign=0.5, yalign=0.5)
        
        add g.make_button("light-blue", "light-blue.png", xalign=0.5, yalign=0.5)
        add g.make_button("dark-blue", "dark-blue.png", xalign=0.5, yalign=0.5)

        # The screen is responsible for returning to the main menu. It could also
        # navigate to other gallery screens.
        
        grid 1 9:
            
            xfill True
            yfill True
        
            textbutton "Page 01" action ShowMenu("gallery_1")
            textbutton "Page 02" action ShowMenu("gallery_2")
            textbutton "Page 03" action ShowMenu("gallery_3")
            textbutton "Page 04" action ShowMenu("gallery_4")
            textbutton "Page 05" action ShowMenu("gallery_5")
            textbutton "Page 06" action ShowMenu("gallery_6")
            textbutton "Page 07" action ShowMenu("gallery_7")
            textbutton "Page 08" action ShowMenu("gallery_8")
            textbutton "Return" action Return() xalign 0.5 yalign 0.5
        
        
screen gallery_8:

    # Ensure this replaces the main menu.
    tag menu

    # The background.
    add "logo"

    # A grid of buttons.
    grid 3 3:

        xfill True
        yfill True

        # Call make_button to show a particular button.
        
        add g.make_button("pink", "pink.png", xalign=0.5, yalign=0.5)        
        add g.make_button("red", "red.png", xalign=0.5, yalign=0.5)        
        add g.make_button("orange", "orange.png", xalign=0.5, yalign=0.5)
        
        add g.make_button("yellow", "yellow.png", xalign=0.5, yalign=0.5)        
        add g.make_button("green", "green.png", xalign=0.5, yalign=0.5)        
        add g.make_button("light-blue", "light-blue.png", xalign=0.5, yalign=0.5)
        
        add g.make_button("dark-blue", "dark-blue.png", xalign=0.5, yalign=0.5)
        add g.make_button("purple", "purple.png", xalign=0.5, yalign=0.5)

        # The screen is responsible for returning to the main menu. It could also
        # navigate to other gallery screens.
        
        grid 1 9:
            
            xfill True
            yfill True
        
            textbutton "Page 01" action ShowMenu("gallery_1")
            textbutton "Page 02" action ShowMenu("gallery_2")
            textbutton "Page 03" action ShowMenu("gallery_3")
            textbutton "Page 04" action ShowMenu("gallery_4")
            textbutton "Page 05" action ShowMenu("gallery_5")
            textbutton "Page 06" action ShowMenu("gallery_6")
            textbutton "Page 07" action ShowMenu("gallery_7")
            textbutton "Page 08" action ShowMenu("gallery_8")
            textbutton "Return" action Return() xalign 0.5 yalign 0.5
    
    
##############################################################################
# Game Menu
#
# Screen that appears when the player presses the escape button.

image logo = "logo.png"

screen game_menu:
    tag menu
    
    add "logo"
   
    vbox:
        pos (0.5, 0.5)
        anchor (0.5, 0.5)
        textbutton _("Continue") action Return()
        textbutton _("Save Game") action ShowMenu("save")
        textbutton _("Load Game") action ShowMenu("load")
        textbutton _("Character Data") action ShowMenu("info")
        textbutton _("Preferences") action ShowMenu("preferences")
        textbutton _("Main Menu") action MainMenu()
        textbutton _("Help") action Help()
        textbutton _("Quit") action Quit()



##############################################################################
# Character Data
#
# Screen that's used to display character information.


screen info:
    
    # Ensure this replaces the main menu.
    tag menu
    
    frame:
        xalign 1.0
        vbox:
            textbutton "View Codex" action Show("codex")

screen codex:
    
    # Ensure this replaces the main menu.
    tag menu
    
    frame:
        xalign 0.5
        yalign 0.5
        vbox:
            if persistent.entry1:
                text "Entry 1"
                text "Blah blah, here is your info.  Below is your image."
                add "image.png"
            else:
                text "????????"
                
            # The screen is responsible for returning to the main menu. It could also
            # navigate to other gallery screens.
            textbutton "Close" action Return()



##############################################################################
# Schedule
#
# Screen that's used to set a schedule for the month. 

screen schedule:

    frame:
        style_group "schedule"       
        xalign .5
        yalign .33
       
        #This controls vertical spacing
        has vbox spacing 20

        label "Monthly Schedule"

        grid 4 5:
            transpose True
           
            label "First Week"
            textbutton "School" action ShowMenu ("school_1")
            textbutton "Work" action ShowMenu ("work_1")
            textbutton "Travel" action ShowMenu ("travel_1")
            textbutton "Rest" action ShowMenu ("rest_1")
           
            label "Second Week"
            textbutton "School" action ShowMenu ("school_2")
            textbutton "Work" action ShowMenu ("work_2")
            textbutton "Travel" action ShowMenu ("travel_2")
            textbutton "Rest" action ShowMenu ("rest_2")
           
            label "Third Week"
            textbutton "School" action ShowMenu ("school_3")
            textbutton "Work" action ShowMenu ("work_3")
            textbutton "Travel" action ShowMenu ("travel_3")
            textbutton "Rest" action ShowMenu ("rest_3")
           
            label "Fourth Week"
            textbutton "School" action ShowMenu ("school_5")
            textbutton "Work" action ShowMenu ("work_4")
            textbutton "Travel" action ShowMenu ("travel_4")
            textbutton "Rest" action ShowMenu ("rest_4")

        textbutton "Select" action Return() xalign .5

init python:
    #This controls minimum button length
    style.schedule_button.xminimum = 180
    style.schedule_label.xalign = .5

#WEEK 01

screen school_1:
    
    frame:
        style_group "schedule"       
        xalign .5
        yalign .33
       
        #This controls vertical spacing
        has vbox spacing 20

        label "What Would You Like To Study?"

        grid 1 4:
            transpose True
           
            textbutton "Art" action SetVariable("week01", "Art")
            textbutton "Fencing" action SetVariable("week01", "Fencing")
            textbutton "Math" action SetVariable("week01", "Math")
            textbutton "Alchemy" action SetVariable("week01", "Alchemy")

        textbutton "Select" action Return() xalign .5

init python:
    #This controls minimum button length
    style.schedule_button.xminimum = 180
    style.schedule_label.xalign = .5
    
screen work_1:
    
    frame:
        style_group "schedule"       
        xalign .5
        yalign .33
       
        #This controls vertical spacing
        has vbox spacing 20

        label "Where Would You Like To Work?"

        grid 1 4:
            transpose True
           
            textbutton "Church" action SetVariable("week01", "Church")
            textbutton "Farm" action SetVariable("week01", "Farm")
            textbutton "Store" action SetVariable("week01", "Store")
            textbutton "Chores" action SetVariable("week01", "Chores")

        textbutton "Select" action Return() xalign .5

init python:
    #This controls minimum button length
    style.schedule_button.xminimum = 180
    style.schedule_label.xalign = .5


screen travel_1:
    
    frame:
        style_group "schedule"       
        xalign .5
        yalign .33
       
        #This controls vertical spacing
        has vbox spacing 20

        label "Where Would You Like To Go?"

        grid 1 4:
            transpose True
           
            textbutton "North" action SetVariable("week01", "North")
            textbutton "East" action SetVariable("week01", "East")
            textbutton "South" action SetVariable("week01", "South")
            textbutton "West" action SetVariable("week01", "West")

        textbutton "Select" action Return() xalign .5

init python:
    #This controls minimum button length
    style.schedule_button.xminimum = 180
    style.schedule_label.xalign = .5


screen rest_1:
    
    frame:
        style_group "schedule"       
        xalign .5
        yalign .33
       
        #This controls vertical spacing
        has vbox spacing 20

        label "Where Would You Like To Rest?"

        grid 1 4:
            transpose True
           
            textbutton "Home" action SetVariable("week01", "Home")
            textbutton "Playground" action SetVariable("week01", "Playground")
            textbutton "Vacation" action SetVariable("week01", "Vacation")
            textbutton "Hospital" action SetVariable("week01", "Hospital")

        textbutton "Select" action Return() xalign .5

init python:
    #This controls minimum button length
    style.schedule_button.xminimum = 180
    style.schedule_label.xalign = .5


#WEEK 02

screen school_2:
    
    frame:
        style_group "schedule"       
        xalign .5
        yalign .33
       
        #This controls vertical spacing
        has vbox spacing 20

        label "What Would You Like To Study?"

        grid 1 4:
            transpose True
           
            textbutton "Art" action SetVariable("week02", "Art")
            textbutton "Fencing" action SetVariable("week02", "Fencing")
            textbutton "Math" action SetVariable("week02", "Math")
            textbutton "Alchemy" action SetVariable("week02", "Alchemy")

        textbutton "Select" action Return() xalign .5

init python:
    #This controls minimum button length
    style.schedule_button.xminimum = 180
    style.schedule_label.xalign = .5
    
screen work_2:
    
    frame:
        style_group "schedule"       
        xalign .5
        yalign .33
       
        #This controls vertical spacing
        has vbox spacing 20

        label "Where Would You Like To Work?"

        grid 1 4:
            transpose True
           
            textbutton "Church" action SetVariable("week02", "Church")
            textbutton "Farm" action SetVariable("week02", "Farm")
            textbutton "Store" action SetVariable("week02", "Store")
            textbutton "Chores" action SetVariable("week02", "Chores")

        textbutton "Select" action Return() xalign .5

init python:
    #This controls minimum button length
    style.schedule_button.xminimum = 180
    style.schedule_label.xalign = .5


screen travel_2:
    
    frame:
        style_group "schedule"       
        xalign .5
        yalign .33
       
        #This controls vertical spacing
        has vbox spacing 20

        label "Where Would You Like To Go?"

        grid 1 4:
            transpose True
           
            textbutton "North" action SetVariable("week02", "North")
            textbutton "East" action SetVariable("week02", "East")
            textbutton "South" action SetVariable("week02", "South")
            textbutton "West" action SetVariable("week02", "West")

        textbutton "Select" action Return() xalign .5

init python:
    #This controls minimum button length
    style.schedule_button.xminimum = 180
    style.schedule_label.xalign = .5


screen rest_2:
    
    frame:
        style_group "schedule"       
        xalign .5
        yalign .33
       
        #This controls vertical spacing
        has vbox spacing 20

        label "Where Would You Like To Rest?"

        grid 1 4:
            transpose True
           
            textbutton "Home" action SetVariable("week02", "Home")
            textbutton "Playground" action SetVariable("week02", "Playground")
            textbutton "Vacation" action SetVariable("week02", "Vacation")
            textbutton "Hospital" action SetVariable("week02", "Hospital")

        textbutton "Select" action Return() xalign .5

init python:
    #This controls minimum button length
    style.schedule_button.xminimum = 180
    style.schedule_label.xalign = .5
    
    
#WEEK 03

screen school_3:
    
    frame:
        style_group "schedule"       
        xalign .5
        yalign .33
       
        #This controls vertical spacing
        has vbox spacing 20

        label "What Would You Like To Study?"

        grid 1 4:
            transpose True
           
            textbutton "Art" action SetVariable("week03", "Art")
            textbutton "Fencing" action SetVariable("week03", "Fencing")
            textbutton "Math" action SetVariable("week03", "Math")
            textbutton "Alchemy" action SetVariable("week03", "Alchemy")

        textbutton "Select" action Return() xalign .5

init python:
    #This controls minimum button length
    style.schedule_button.xminimum = 180
    style.schedule_label.xalign = .5
    
screen work_3:
    
    frame:
        style_group "schedule"       
        xalign .5
        yalign .33
       
        #This controls vertical spacing
        has vbox spacing 20

        label "Where Would You Like To Work?"

        grid 1 4:
            transpose True
           
            textbutton "Church" action SetVariable("week03", "Church")
            textbutton "Farm" action SetVariable("week03", "Farm")
            textbutton "Store" action SetVariable("week03", "Store")
            textbutton "Chores" action SetVariable("week03", "Chores")

        textbutton "Select" action Return() xalign .5

init python:
    #This controls minimum button length
    style.schedule_button.xminimum = 180
    style.schedule_label.xalign = .5


screen travel_3:
    
    frame:
        style_group "schedule"       
        xalign .5
        yalign .33
       
        #This controls vertical spacing
        has vbox spacing 20

        label "Where Would You Like To Go?"

        grid 1 4:
            transpose True
           
            textbutton "North" action SetVariable("week03", "North")
            textbutton "East" action SetVariable("week03", "East")
            textbutton "South" action SetVariable("week03", "South")
            textbutton "West" action SetVariable("week03", "West")

        textbutton "Select" action Return() xalign .5

init python:
    #This controls minimum button length
    style.schedule_button.xminimum = 180
    style.schedule_label.xalign = .5


screen rest_3:
    
    frame:
        style_group "schedule"       
        xalign .5
        yalign .33
       
        #This controls vertical spacing
        has vbox spacing 20

        label "Where Would You Like To Rest?"

        grid 1 4:
            transpose True
           
            textbutton "Home" action SetVariable("week03", "Home")
            textbutton "Playground" action SetVariable("week03", "Playground")
            textbutton "Vacation" action SetVariable("week03", "Vacation")
            textbutton "Hospital" action SetVariable("week03", "Hospital")

        textbutton "Select" action Return() xalign .5

init python:
    #This controls minimum button length
    style.schedule_button.xminimum = 180
    style.schedule_label.xalign = .5


#WEEK 04

screen school_4:
    
    frame:
        style_group "What Would You Like To Study?"       
        xalign .5
        yalign .33
       
        #This controls vertical spacing
        has vbox spacing 20

        label "Pick a Class"

        grid 1 4:
            transpose True
           
            textbutton "Art" action SetVariable("week04", "Art")
            textbutton "Fencing" action SetVariable("week04", "Fencing")
            textbutton "Math" action SetVariable("week04", "Math")
            textbutton "Alchemy" action SetVariable("week04", "Alchemy")

        textbutton "Select" action Return() xalign .5

init python:
    #This controls minimum button length
    style.schedule_button.xminimum = 180
    style.schedule_label.xalign = .5
    
screen work_4:
    
    frame:
        style_group "schedule"       
        xalign .5
        yalign .33
       
        #This controls vertical spacing
        has vbox spacing 20

        label "Where Would You Like To Work?"

        grid 1 4:
            transpose True
           
            textbutton "Church" action SetVariable("week04", "Church")
            textbutton "Farm" action SetVariable("week04", "Farm")
            textbutton "Store" action SetVariable("week04", "Store")
            textbutton "Chores" action SetVariable("week04", "Chores")

        textbutton "Select" action Return() xalign .5

init python:
    #This controls minimum button length
    style.schedule_button.xminimum = 180
    style.schedule_label.xalign = .5


screen travel_4:
    
    frame:
        style_group "schedule"       
        xalign .5
        yalign .33
       
        #This controls vertical spacing
        has vbox spacing 20

        label "Where Would You Like To Go?"

        grid 1 4:
            transpose True
           
            textbutton "North" action SetVariable("week04", "North")
            textbutton "East" action SetVariable("week04", "East")
            textbutton "South" action SetVariable("week04", "South")
            textbutton "West" action SetVariable("week04", "West")

        textbutton "Select" action Return() xalign .5

init python:
    #This controls minimum button length
    style.schedule_button.xminimum = 180
    style.schedule_label.xalign = .5


screen rest_4:
    
    frame:
        style_group "schedule"       
        xalign .5
        yalign .33
       
        #This controls vertical spacing
        has vbox spacing 20

        label "Where Would You Like To Rest?"

        grid 1 4:
            transpose True
           
            textbutton "Home" action SetVariable("week04", "Home")
            textbutton "Playground" action SetVariable("week04", "Playground")
            textbutton "Vacation" action SetVariable("week04", "Vacation")
            textbutton "Hospital" action SetVariable("week04", "Hospital")

        textbutton "Select" action Return() xalign .5

init python:
    #This controls minimum button length
    style.schedule_button.xminimum = 180
    style.schedule_label.xalign = .5

##############################################################################
# Preferences
#
# Screen that allows the user to change the preferences.
# http://www.renpy.org/doc/html/screen_special.html#prefereces
    
screen preferences:

    tag menu

    # Include the navigation.
    use navigation

    # Put the navigation columns in a three-wide grid.
    grid 3 1:
        style_group "prefs"
        xfill True

        # The left column.
        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Display")
                textbutton _("Window") action Preference("display", "window")
                textbutton _("Fullscreen") action Preference("display", "fullscreen")

            frame:
                style_group "pref"
                has vbox

                label _("Transitions")
                textbutton _("All") action Preference("transitions", "all")
                textbutton _("None") action Preference("transitions", "none")

            frame:
                style_group "pref"
                has vbox

                label _("Text Speed")
                bar value Preference("text speed")

            frame:
                style_group "pref"
                has vbox

                textbutton _("Joystick...") action Preference("joystick")


        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Skip")
                textbutton _("Seen Messages") action Preference("skip", "seen")
                textbutton _("All Messages") action Preference("skip", "all")

            frame:
                style_group "pref"
                has vbox

                textbutton _("Begin Skipping") action Skip()

            frame:
                style_group "pref"
                has vbox

                label _("After Choices")
                textbutton _("Stop Skipping") action Preference("after choices", "stop")
                textbutton _("Keep Skipping") action Preference("after choices", "skip")

            frame:
                style_group "pref"
                has vbox

                label _("Auto-Forward Time")
                bar value Preference("auto-forward time")

        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Music Volume")
                bar value Preference("music volume")

            frame:
                style_group "pref"
                has vbox

                label _("Sound Volume")
                bar value Preference("sound volume")

                if config.sample_sound:
                    textbutton _("Test"):
                        action Play("sound", config.sample_sound)
                        style "soundtest_button"

            frame:
                style_group "pref"
                has vbox

                label _("Voice Volume")
                bar value Preference("voice volume")

                if config.sample_voice:
                    textbutton "Test":
                        action Play("voice", config.sample_voice)
                        style "soundtest_button"

init -2 python:
    style.pref_frame.xfill = True
    style.pref_frame.xmargin = 5
    style.pref_frame.top_margin = 5

    style.pref_vbox.xfill = True

    style.pref_button.size_group = "pref"
    style.pref_button.xalign = 1.0

    style.pref_slider.xmaximum = 192
    style.pref_slider.xalign = 1.0

    style.soundtest_button.xalign = 1.0


##############################################################################
# Yes/No Prompt
#
# Screen that asks the user a yes or no question.
# http://www.renpy.org/doc/html/screen_special.html#yesno-prompt
    
screen yesno_prompt:

    modal True

    window:
        style "gm_root"

    frame:
        style_group "yesno"

        xfill True
        xmargin .05
        ypos .1
        yanchor 0
        ypadding .05
        
        has vbox:
            xalign .5
            yalign .5
            spacing 30
            
        label _(message):
            xalign 0.5

        hbox:
            xalign 0.5
            spacing 100
            
            textbutton _("Yes") action yes_action
            textbutton _("No") action no_action


init -2 python:    
    style.yesno_button.size_group = "yesno"
    style.yesno_label_text.text_align = 0.5


##############################################################################
# Quick Menu
#
# A screen that's included by the default say screen, and adds quick access to
# several useful functions.
screen quick_menu:

    # Add an in-game quick menu.
    hbox:
        style_group "quick"
    
        xalign 1.0
        yalign 1.0

        textbutton _("Q.Save") action QuickSave()
        textbutton _("Q.Load") action QuickLoad()
        textbutton _("Save") action ShowMenu('save')
        textbutton _("Skip") action Skip()
        textbutton _("Auto") action Preference("auto-forward", "toggle")
        textbutton _("Prefs") action ShowMenu('preferences')
        
init -2 python:
    style.quick_button.set_parent('default')
    style.quick_button.background = None
    style.quick_button.xpadding = 5

    style.quick_button_text.set_parent('default')
    style.quick_button_text.size = 12
    style.quick_button_text.idle_color = "#8888"
    style.quick_button_text.hover_color = "#ccc"
    style.quick_button_text.selected_idle_color = "#cc08"
    style.quick_button_text.selected_hover_color = "#cc0"
    style.quick_button_text.insensitive_color = "#4448"
    
    # Set a default value for the auto-forward time, and note that AFM is
    # turned off by default.
    config.default_afm_time = 10
    config.default_afm_enable = False
    
    
